#
# spec file for package fastjet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fastjet
Version:        3.4.2
Release:        1.5
Summary:        Package for jet finding in pp and e+e- collisions
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://fastjet.fr/
Source:         http://fastjet.fr/repo/%{name}-%{version}.tar.gz
BuildRequires:  cgal-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python3-devel

%description
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation.

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

%package -n libfastjet0
Summary:        Shared libraries for fastjet core package
Group:          Development/Libraries/C and C++

%description -n libfastjet0
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation.

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the shared libraries for fastjet and its
plugins.

%package -n fastjet-devel
Summary:        Shared libraries for fastjet core package
Group:          Development/Libraries/C and C++
Requires:       cgal-devel
Requires:       libfastjet0 = %{version}

%description -n fastjet-devel
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation.

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the header files for development with fastjet.

%package -n fastjet-plugin-siscone
Summary:        SISCone plugin for fastjet
Group:          Development/Libraries/C and C++

%description -n fastjet-plugin-siscone
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation.

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides shared libraries for SISCone plugin for
fastjet.

%package -n fastjet-plugin-siscone-devel
Summary:        SISCone plugin for fastjet
Group:          Development/Libraries/C and C++
Requires:       fastjet-devel = %{version}
Requires:       fastjet-plugin-siscone = %{version}

%description -n fastjet-plugin-siscone-devel
FastJet is a software package for jet finding in pp and e+e-
collisions. It includes fast native implementations of many sequential
recombination clustering algorithms, plugins for access to a range of
cone jet finders and tools for advanced jet manipulation.

It provides a fast implementation of several
longitudinally invariant sequential recombination jet algorithms, in
particular the longitudinally invariant kt jet algorithm, the
inclusive longitudinally invariant version of the Cambridge/Aachen
jet-algorithm, and the inclusive anti-kt algorithm.

This package provides the develoment files for SISCone plugin for
fastjet.

%package -n python3-%{name}
Summary:        Python3 bindings for fastjet
Group:          Development/Libraries/Python

%description -n python3-%{name}
FastJet is a software package for jet finding in pp and e+e-
collisions.

This package provides python3 bindings for fastjet.

%prep
%setup -q

%build
# Don't use --enable-cgal-header-only option up to 15.2
%configure --disable-static \
           --enable-allcxxplugins \
%if 0%{?sle_version} < 120000 || 0%{?sle_version} > 150200
           --enable-cgal-header-only \
%endif
           --enable-pyext \
           --enable-cgal
%make_build

%install
%make_install

# REMOVE libtool ARCHIVES
find %{buildroot} -type f -name "*.la" -delete -print

# Remove rpaths from fastjet-config script
sed -i "s|-Wl,-rpath,[^ ]\+||g" %{buildroot}%{_bindir}/fastjet-config

%fdupes %{buildroot}%{python3_sitelib}/

%post -n libfastjet0 -p /sbin/ldconfig
%postun -n libfastjet0 -p /sbin/ldconfig
%post -n fastjet-plugin-siscone -p /sbin/ldconfig
%postun -n fastjet-plugin-siscone -p /sbin/ldconfig

%files -n libfastjet0
%license COPYING
%doc ChangeLog README
%{_libdir}/libfastjet.so.*
%{_libdir}/libfastjettools.so.*
%{_libdir}/libfastjetplugins.so.*

%files -n fastjet-devel
%{_bindir}/fastjet-config
%{_libdir}/libfastjet.so
%{_libdir}/libfastjettools.so
%{_libdir}/libfastjetplugins.so
%{_includedir}/fastjet/
%{_datadir}/%{name}/

%files -n fastjet-plugin-siscone
%{_libdir}/libsiscone*.so.*

%files -n fastjet-plugin-siscone-devel
%{_libdir}/libsiscone*.so
%{_includedir}/siscone/

%files -n python3-%{name}
%{python3_sitelib}/fastjet.*
%{python3_sitelib}/__pycache__/*
%{python3_sitearch}/_fastjet.*

%changelog
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 3.4.2
  * Bug fixes:
    + small fix in ClosestPair2D class for compatibility with c++20
    + SISCone updated to 3.0.6, which eliminates default
  - ffast-math compile-time argument, which could cause
    interference with other code.
- update to 3.4.1
  * New features:
    + JetDefinition has a new clustering strategy, N2PlainEEAccurate
    + two new functions to make it possible for plugin algorithms
    to modify user info:
  - PseudoJet::set_user_info_shared_ptr(...)
  - ClusterSequence::plugin_non_const_jet(...)
  * Bug fixes:
    + Resolved MAJOR BUG that arose with full thread-safety enabled
    + eliminated NaN from square-root of negative mean areas in
    background estimation (now returns zero)
  + Other changes:
    + auto_ptr interface is now disabled by default
* Fri Jan  7 2022 Atri Bhattacharya <badshah400@gmail.com>
- Remove rpath references from fastjet-configs script.
* Fri Aug 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- update to 3.4.0
- New features:
  * addition of support for thread safety. It requires a compiler
  * supporting the C++11 standard (or later) and must be explicitly
    enabled at configure time. There are two options
  - the --enable-limited-thread-safety configure option is generally
    sufficient if each thread is processing entirely distinct events.
    It should have essentially no speed overhead.
  - the --enable-thread-safety configure option is required if you
    want to be able to read/copy/process a common set of PseudoJets
    across multiple threads. Depending on the system, our tests have
    shown speed penalties of up to 10-15%%. For further details, see
    section 10 of the manual
  * The jet area infrastructure has new calls to facilitate
    reproducible multi-threaded running: AreaDefinition::with_fixed_seed(seed)
    and GhostedAreaSpec::get_last_seed(seed). See section 10.3.1 of the manual.
  * The background estimators have a new interface to facilitate
    reproducible multi-threaded running: BackgroundEstimatorBase::estimate(...)
    returns a BackgroundEstimate object, which contains rho, sigma, etc. For
    details on using it, see sections 8 and 10.3.2 of the manual. The
    Subtractor class has been updated to use this.
  * Improvements to existing features:
  * the Python interface now has improved exceptions (a fastjet Error
    is translated into a FastJetError python exception) and can be
    more easily be used with projects using FastJet that want to
    define their own python wrappers. Thanks to Patrick Komiske
    for the suggestions.
  * PxConePlugin now has an optional mode argument for e+e- running
    (mode=1) instead of pp running (mode=2). Thanks to Stefan Kluth
    for the suggestion.
  * Bug fixes:
  * the Fortran interface to e+e- interface now returns jets ordered
    in decreasing energy rather than decreasing transverse momentum.
  * Changes compared to the fastjet-3.4.0-beta.1 release:
  * added set_default_stream_and_mutex to Error and LimitedWarnings
    to help guard against garbled output.
- Build with enable-cgal-header-only for openSUSE > Leap 15.2
  (where cgal version is >= 5).
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3.4:
  * clarifications in documentation for handling of CGAL v5.
  * resolved run-time crash with certain strict g++ options and
    compilation issue with oracle c++.
  * included SISCone v3.0.5 (fixes signed-unsigned mismatch, no
    impact on results).
- Summary of changes from v3.3.2 -> v3.3.3:
  * improved treatment of CGAL in the build system.
  * fixed an overflow issue in the JadePlugin.
- Enable cgal linking; BuildRequires and Requires for -devel pkg:
  cgal-devel.
- Run spec-cleaner for minor cleanups.
* Fri Nov  8 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.3.2:
  * Improved the shared-library behaviour by setting the proper
    inter-dependences
  * Included SISCone v3.0.4 with a similar fix
- Changes from version 3.3.1:
  * Main FastJet license clarified as being GPL v2 or later
  * Added theta() and cos_theta() members to PseudoJet
  * Added a --with-cgal-boostdir=... configure option to handle
    cases where CGAL uses a non-standard Boost installation path
  * Fixed compilation bug in the SISCone interface
- Use fdupes to link duplicated files.
- Update License to GPL-2.0-or-later.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 3.3.0:
  * This release adds a first version of a Python interface to
    FastJet
- Enable python bindings:
  * Split out a python-fastjet subpackage.
  * Add python BuildRequires
  * Pass --enable-pyext to configure
  * Package python examples.
* Sat Nov 12 2016 badshah400@gmail.com
- Update to version 3.2.1:
  * Added a missing assignment operator for ClusterSequence.
  * Eliminated a warning about unused variables when assertions
    are disabled.
  * Included SISCone-3.0.3 which now installs config.h to improve
    build stability.
- Changes from version 3.2.0:
  * Exposed the N2Plain and N2Tiled strategies for 3rd-party
    clustering algorithms under the form of two new classes
    (NNFJN2Plain and NNFJN2Tiled), similar to NNH.
  * Included version 3.0.2 SISCone with minor bug fixes.
  * Made template implementation of
    PseudoJet::obj_sorted_by_values() public.
  * Added a --guess-prefix option to fastjet-config (guesses
    prefix from location of fastjet-config instead of prefix from
    configure).
  * Added a --disable-auto-ptr option to configure.
  * Added internal helpers for C++11 and C++14 features:
    compile-time deprecation and the override keyword.
  * Small tweaks to the build system.
  * fjcore now ships with an illustrative fortran wrapper and
    example.
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.1.3
  * disables JetDefinition::operator(...) when CINT is detected, for
    ROOT v5 compatibility
  * works around an issue with recent versions of CGAL and the clang
    compiler
- Changes from version 3.1.2
  * fixes a rounding error issue in the "lazy" clustering strategies
    that, in rare cases, caused infinite loops or crashes
  * adds a check on clustering's internal consistency; a failure will
    throw a new "InternalError" exception (derived from Error)
  * fixes a bug in the extraction of the fjcore code that resulted in
    fjcore failing for high multiplicities (~1000). This issue only
    affects fjcore, not the full fastjet library
* Mon Jan 12 2015 p.drouand@gmail.com
- Update to version 3.1.1
  + fix to area support for Filter with Cambridge/Aachen jets and subjets
  + GridMedianBackgroundEstimator has new constructor and RectangularGrid
    as public base
  + added virtual destructor to TilingBase class
* Fri Dec  6 2013 badshah400@gmail.com
- Initial version
